unit ICGlobals;

(*	This file is part of the Internet Configuration system and is placed in the public domain for the benefit of all.

	This module holds all that random global cruft that applications accumulate
	over time.
*)

interface

	uses
		Types;

	(* The following Booleans provide simple and commonly used system information
		to the rest of the application. These are set up by InitICGlobals.
	*)
	
	var
		gHasSystem7: Boolean;
		gHasAppleEvents: Boolean;
		gHasAliasManager: Boolean;
		gHasNewStandardFile: Boolean;
		gHasColourQuickDraw: Boolean;
		gHasComponentManager: Boolean;
		gHasHelpManager : Boolean;
		gApplicationResourceRefNum: integer;
		gInForeground: Boolean;		(* See the InForeground function below. *)
		
		gQuitNow: Boolean;
		
		gApplicationVersion: VersRec;

	(* ***** Error Handling ***** *)
	
	type
		ErrorAction = (
			acDoThis, acInstallComponent, acOpenWindow, acNewDocument,
			acOpenDocument, acCloseWindow, acSave, acQuit, 
			acStartApplication, acGetExample, acChooseApplication, acRemoveComponent, 
			acSetDefaults, acSort, acLaunchHelper
			);

	procedure DisplayError (action: ErrorAction; err: OSStatus);
		(* This routine displays an error dialog, parameterised by the action
			and the error number.  The typical error message 
			would be: Cannot do <action> because <error>.
		*)

	(* ***** Misc Stuff ***** *)
	
	function InForeground: Boolean;
		(* This function provides a high-reliability way of determining whether
			we're in the foreground. Under System 6, the only way to do this is to
			keep track of a Boolean through the various suspend and resume events.
			Under System 7, you can simply ask the Process Manager.  This
			routine does the right thing for thes two cases.
		*)

	procedure InitICGlobals;
		(* This routine initialises the various Booleans that describe the
			capabilities of the system.
		*)

implementation

	uses
		OSUtils,
		Resources,
		GestaltEqu,
		Processes,
		Errors,
		Dialogs,

		ICResources,		
		ICStringLists,
		ICMiscSubs;
		
	procedure DisplayError (action: ErrorAction; errNum: OSStatus);
		(* See comment in interface part. *)
		var
			junk: integer;
	begin
		if (errNum <> noErr) and (errNum <> userCanceledErr) then begin
			InitCursor;
			ParamText(	GetIndStr(rActionStrings, ord(action) + 1), 
								NewLookupError(rMainErrorList, errNum), 
								DecStr(errNum), 
								'');
			junk := StopAlert(rErrorAlert, nil);
		end; (* if *)
	end; (* DisplayError *)

	function InForeground: Boolean;
		(* See comment in interface part. *)
		var
			gestaltResult: longint;
			ourPSN: ProcessSerialNumber;
			frontPSN: ProcessSerialNumber;
			front: Boolean;
	begin
		(* If we have a Process Manager, call it and update the gInForeground variable. *)
		if (Gestalt(gestaltOSAttr, gestaltResult) = noErr) & (btst(gestaltResult, gestaltLaunchControl)) then begin
			if (GetCurrentProcess(ourPSN) = noErr) & (GetFrontProcess(frontPSN) = noErr) then begin
				if SameProcess(ourPSN, frontPSN, front) = noErr then
					gInForeground := front;
			end; (* if *)
		end; (* if *)
		InForeground := gInForeground;
	end; (* InForeground *)

	procedure InitICGlobals;
		(* See comment in interface part. *)
		var
			gestaltValue: longint;
			sysEnv: SysEnvRec;
			versH: VersRecHndl;
			junk : Boolean;
	begin
		gApplicationResourceRefNum := CurResFile;
		(* Can't call Gestalt to determine whether we have Colour QuickDraw because
			certain system (PowerBook 100 running System 7.0 for example) return
			true when they shouldn't.
		*)
		gHasColourQuickDraw := (SysEnvirons(1, sysEnv) = noErr) & sysEnv.hasColorQD;
		gHasSystem7 := (Gestalt(gestaltSystemVersion, gestaltValue) = noErr) & (gestaltValue >= $0700);
		gHasAppleEvents := (Gestalt(gestaltAppleEventsAttr, gestaltValue) = noErr) & (btst(gestaltValue, gestaltAppleEventsPresent));
		gHasNewStandardFile := (Gestalt(gestaltStandardFileAttr, gestaltValue) = noErr) & (btst(gestaltValue, gestaltStandardFile58));
		gHasAliasManager := (Gestalt(gestaltAliasMgrAttr, gestaltValue) = noErr) & (btst(gestaltValue, gestaltAliasMgrPresent));
		gHasComponentManager := (Gestalt(gestaltComponentMgr, gestaltValue) = noErr) & (gestaltValue > 0);
		gHasHelpManager := (Gestalt(gestaltHelpMgrAttr, gestaltValue) = noErr) & btst(gestaltValue, gestaltHelpMgrPresent);

		(* Assume we're starting in the foreground and then call
			InForeground to correct that assumption if we have
			a Process Manager.
		*)
		gInForeground := true;
		junk := InForeground;

		versH := VersRecHndl(Get1Resource('vers', 1));
		if versH <> nil then begin
			gApplicationVersion := versH^^;
		end else begin
			longint(gApplicationVersion.numericVersion) := 0;
			gApplicationVersion.countryCode := 0;
			gApplicationVersion.shortVersion := '';
		end; (* if *)

		gQuitNow := false;
	end; (* InitICGlobals *)

end. (* ICGlobals *)