unit ICGreyBoxWhats;

(*	This file is part of the Internet Configuration system and is placed in the public domain for the benefit of all.

	This module implements the Grey Box What, an extraordinarily simple What
	that just draws a grey box.  This is used as an item delimiter in various
	IC dialogs.
*)

interface

	uses
		ICWindowGlobals;

	(* ***** Standard What Interface ***** *)
	
	(* See the comments in ICWindowGlobals. *)

	function WhatInitGreyBox : OSStatus;
	function WhatOpenGreyBox (wt: WindowType; item: integer): OSStatus;

implementation

	uses
		ICDialogs;

	var
		gGreyBoxUserItemUpdateUPP : UserItemUPP;

	(* ***** Drawing ***** *)

	procedure GreyBoxUserItemUpdateProc (window: DialogPtr; item: integer);
		(* This routine is called by the Dialog Manager to redraw the grey
			box user item.
		*)
		var
			oldPenState : PenState;
			itemRect : Rect;
	begin
		GetPenState(oldPenState);
		PenNormal;
		PenPat(qd.gray);
		GetDItemRect(window, item, itemRect);
		FrameRect(itemRect);
		SetPenState(oldPenState);
	end; (* GreyBoxUserItemUpdateProc *)

	(* ***** Standard What Interface ***** *)

	(* ***** What Init ***** *)

	function WhatInitGreyBox : OSStatus;
	begin
		gGreyBoxUserItemUpdateUPP := NewUserItemProc(@GreyBoxUserItemUpdateProc);
		WhatInitGreyBox := noErr;
	end; (* WhatInitGreyBox *)

	(* ***** What Open ***** *)

	function WhatOpenGreyBox (wt: WindowType; item: integer): OSStatus;
		(* See the comments in ICWindowGlobals. *)
	begin
		SetDItemHandle(gWindows[wt].window, item, gGreyBoxUserItemUpdateUPP);
		WhatOpenGreyBox := noErr;
	end; (* WhatOpenGreyBox *)
	
end. (* ICGreyBoxWhats *)